@@ -86,7 +86,7 @@ namespace boost {
 
         //! Find first algorithm ( case insensitive )
         /*!
-            Search for the first occurence of the substring in the input. 
+            Search for the first occurrence of the substring in the input. 
             Searching is case insensitive.
             
             \param Input A string which will be searched.
@@ -293,7 +293,7 @@ namespace boost {
             If the "token compress mode" is enabled, adjacent tokens are considered to be one match.
             
             \param Input A input string.
-            \param Pred An unary predicate to identify a token
+            \param Pred A unary predicate to identify a token
             \param eCompress Enable/Disable compressing of adjacent tokens
             \return 
                 An \c iterator_range delimiting the match. 
